<template>
    <div class="container">
        <div class="header">
            <div class="title">
                <i class="title-icon"></i>
                <span class="title-text">病害管理统计</span>
            </div>
            <i class="back-icon" @click="handleReset"></i>
        </div>
        <div class="search">
            <el-date-picker
                v-model="year"
                type="year"
                placeholder="请选择年限"
                value-format="yyyy"
                style="margin-right: 10px"
            >
                <!--  @change="changeYear" -->
            </el-date-picker>
            <el-button size="small" @click="findinfo" type="primary">查询</el-button>
            <el-button size="small" @click="reset" type="plain"> 重置 </el-button>
        </div>
        <div class="table">
            <el-table
                :data="tableData"
                stripe
                v-loading="loading"
                @row-click="hanldeRowClick"
                @cell-click="handleCellClick"
                header-cell-class-name="custom-header-cell"
                cell-class-name="custom-cell"
            >
                <el-table-column label="序号" type="index" width="70" align="center">
                </el-table-column>
                <el-table-column
                    align="center"
                    prop="name"
                    label="名称"
                    column-key="UntreatedDisease"
                >
                    <template v-slot="{row}">
                        <i class="el-icon-arrow-down" style="margin-right: 10px"></i>
                        {{ row.name }}
                    </template>
                </el-table-column>
                <el-table-column
                    align="center"
                    prop="runCount"
                    column-key="UntreatedDisease"
                    label="待处理病害"
                />
                <el-table-column
                    align="center"
                    prop="finishCount"
                    column-key="virusManagementChild"
                    label="已处理"
                />
                <el-table-column
                    align="center"
                    prop="temporaryCount"
                    label="暂存病害"
                    column-key="temporaryVirus"
                />
            </el-table>
            <div class="table-total">
                <span>{{ tableData.length + 1 }}</span>
                <span>总数</span>
                <span class="item">{{ total.runCount || 0 }}</span>
                <span class="item">{{ total.finishCount || 0 }}</span>
                <span class="item">{{ total.temporaryCount || 0 }}</span>
            </div>
        </div>
        <div class="charts">
            <div class="charts-border">
                <div class="charts_title">
                    <i class="charts_title-icon clumn-icon"></i>
                    <!-- 各部门病害处理状态统计 -->
                    <span class="charts_title-text">处理状态统计</span>
                </div>
                <div id="column" style="height: 100%; width: 100%"></div>
            </div>
            <div class="charts-border">
                <div class="charts_title">
                    <i class="yhxt yhxt-B-zhexiantu"></i>
                    <!-- 各部门病害数量趋势 -->
                    <span class="charts_title-text">数量趋势</span>
                </div>
                <div id="line" style="height: 100%; width: 100%"></div>
            </div>
        </div>
    </div>
</template>

<script>
const BigNumber = require('bignumber.js')
import * as echarts from 'echarts'
export default {
    name: 'VirusManagement',
    data() {
        return {
            tableData: [],
            data: [],
            loading: false,
            pathName: '',
            year: new Date(),
            total: {},
            path: '1419863231459102720,',
        }
    },
    created() {
        this.loadData()
    },
    watch: {
        tableData(newVal) {
            this.total.runCount = this.calculation('runCount', newVal)
            this.total.finishCount = this.calculation('finishCount', newVal)
            this.total.temporaryCount = this.calculation('temporaryCount', newVal)
            this.cloumnCharts(newVal)
            this.lineCharts(newVal)
        },
    },
    methods: {
        reset() {
            this.year = ''
            this.loadData()
        },
        calculation(key, arr) {
            let total = 0
            if (!key || arr.length === 0) return total
            arr.forEach((item) => {
                total += parseInt(item[key])
            })
            if (total === 0) return 0
            return total
        },
        findinfo() {
            let val = this.year
            this.loading = true
            this.$http
                .post('${yhxt}/disease/v1/getDiseaseCountVo?year=' + val)
                .then((res) => {
                    this.tableData = (res && res.status == 200 && res.data) || []
                    this.data = []
                    this.data.push(this.tableData)
                    this.loading = false
                })
        },
        changeYear(val) {
            if (!val) {
                return this.loadData()
            }
            this.loading = true
            this.$http
                .post('${yhxt}/disease/v1/getDiseaseCountVo?year=' + val)
                .then((res) => {
                    this.tableData = (res && res.status == 200 && res.data) || []
                    this.data = []
                    this.data.push(this.tableData)
                    this.loading = false
                })
        },
        handleReset() {
            let length = this.data.length - 1
            if (length === 0) return
            this.tableData = this.data[this.data.length - 2]
            this.data.splice(length, 1)
        },
        hanldeRowClick(row) {
            if (row.chirldren.length == 0 && row.roadSegmentId) {
                this.path += row.roadSegmentId
                return this.$router.push({
                    name: this.pathName,
                    params: {
                        value: row,
                        path: this.path,
                    },
                })
            } else {
                this.path += row.id + ','
            }
            this.tableData = row.chirldren
            this.data.push(row.chirldren)
        },
        handleCellClick(row, column) {
            this.pathName = column.columnKey
        },
        loadData() {
            this.loading = true
            this.$http
                .post(
                    '${yhxt}/disease/v1/getDiseaseCountVo?year=' +
                        new Date().getFullYear()
                )
                .then((res) => {
                    this.tableData = (res && res.status == 200 && res.data) || []
                    this.data = []
                    this.data.push(this.tableData)
                    this.loading = false
                })
                .catch(() => {
                    this.loading = false
                })
        },
        cloumnCharts(data) {
            var chartDom = document.getElementById('column')
            var myChart = echarts.init(chartDom)
            let source = []
            let obj = {
                run: '待处理病害',
                finish: '已处理',
                temporary: '暂存病害',
            }
            data.forEach((item) => {
                source.push({
                    product: item.name,
                    [obj.run]: item.runCount,
                    [obj.finish]: item.finishCount,
                    [obj.temporary]: item.temporaryCount,
                })
            })
            var option
            option = {
                title: {
                    textStyle: {
                        color: '#fff',
                    },
                },
                grid: {
                    top: '20%',
                    left: '10%',
                    right: '10%',
                    bottom: '20%',
                },
                legend: {
                    itemHeight: 10,
                    itemWidth: 10,
                    bottom: 'bottom',
                    bottom: '8%',
                    textStyle: {
                        color: '#fff',
                    },
                },
                tooltip: {
                    trigger: 'axis',
                    axisPointer: {
                        type: 'none',
                    },
                },
                color: [
                    '#16ffae',
                    '#00e6f6',
                    '#6255f8',
                    '#0282b9',
                    '#68c1e5',
                    '#578bf1',
                    '#56d0a3',
                    '#596d90',
                    '#6a5cf1',
                ],
                dataset: {
                    dimensions: ['product', '待处理病害', '已处理', '暂存病害'],
                    source: source,
                },
                xAxis: {
                    type: 'category',
                    axisLabel: {
                        fontSize: 14,
                        color: '#B8C2CC',
                    },
                    axisTick: {
                        show: true,
                        lineStyle: {
                            color: '#B8C2CC',
                        },
                    },
                    axisLine: {
                        show: true,
                        lineStyle: {
                            color: '#274561',
                        },
                    },
                },
                yAxis: {
                    name: '单位：个',
                    nameTextStyle: {
                        color: '#B8C2CC',
                        nameLocation: 'start',
                        fontSize: 18,
                        fontWeight: 700,
                    },
                    type: 'value',
                    splitLine: {show: false}, //去除网格线
                    axisLabel: {
                        textStyle: {
                            color: '#B8C2CC',
                        },
                    },
                    axisTick: {
                        //y轴刻度线
                        show: true,
                        lineStyle: {
                            color: '#B8C2CC',
                        },
                    },
                    axisLine: {
                        //y轴
                        show: true,
                        lineStyle: {
                            color: '#274561',
                        },
                    },
                },
                series: [
                    {
                        type: 'bar',
                        itemStyle: {
                            color: '#578af0',
                        },
                        barWidth: '15%',
                        showBackground: true,
                        backgroundStyle: {
                            color: 'rgba(34, 73, 107, 0.5)',
                        },
                    },
                    {
                        type: 'bar',
                        itemStyle: {
                            color: '#56cfa2',
                        },
                        barWidth: '15%',
                        showBackground: true,
                        backgroundStyle: {
                            color: 'rgba(34, 73, 107, 0.5)',
                        },
                    },
                    {
                        type: 'bar',
                        itemStyle: {
                            color: '#56cfa2',
                        },
                        barWidth: '15%',
                        showBackground: true,
                        backgroundStyle: {
                            color: 'rgba(34, 73, 107, 0.5)',
                        },
                    },
                ],
            }

            option && myChart.setOption(option)
        },
        lineCharts(data) {
            var chartDom = document.getElementById('line')
            var myChart = echarts.init(chartDom)
            let series = []
            let XData = []
            data.forEach((item) => {
                XData.push(item.name)
                let val = new BigNumber(item.runCount)
                val = val.plus(item.finishCount).plus(item.temporaryCount)
                series.push(val.toNumber())
            })
            var option

            option = {
                tooltip: {
                    trigger: 'axis',
                },
                grid: {
                    top: '20%',
                    left: '10%',
                    right: '10%',
                    bottom: '20%',
                },
                legend: {
                    bottom: 'bottom',
                    bottom: 10,
                    textStyle: {
                        color: '#fff',
                    },
                },
                xAxis: {
                    type: 'category',
                    axisLabel: {
                        fontSize: 14,
                        color: '#B8C2CC',
                    },
                    axisTick: {
                        show: true,
                        lineStyle: {
                            color: '#B8C2CC',
                        },
                    },
                    axisLine: {
                        show: true,
                        lineStyle: {
                            color: '#274561',
                        },
                    },
                    data: XData,
                },
                yAxis: {
                    name: '单位：个',
                    nameTextStyle: {
                        color: '#B8C2CC',
                        nameLocation: 'start',
                        fontSize: 18,
                        fontWeight: 700,
                    },
                    type: 'value',
                    splitLine: {
                        show: true,
                        lineStyle: {
                            color: '#274561',
                        },
                    }, //去除网格线
                    axisLabel: {
                        textStyle: {
                            color: '#B8C2CC',
                        },
                    },
                    axisTick: {
                        //y轴刻度线
                        show: true,
                        lineStyle: {
                            color: '#B8C2CC',
                        },
                    },
                    axisLine: {
                        //y轴
                        show: true,
                        lineStyle: {
                            color: '#274561',
                        },
                    },
                },
                series: [
                    {
                        data: series,
                        type: 'line',
                    },
                ],
            }

            option && myChart.setOption(option)
        },
    },
}
</script>

<style lang="scss" scoped>
/deep/ .el-date-editor {
    background-color: #103c5d;
    border: none;
}
/deep/ .el-range-separator {
    color: #fff;
}
/deep/ .el-table th.is-leaf {
    background-color: transparent !important;
}
/deep/ .el-table__row {
    background-color: #0b426e !important;
}
/deep/ .el-table__row--striped {
    background-color: #124873 !important;
}
/deep/ .el-table__header-wrapper {
    border-top-left-radius: 10px;
    border-top-right-radius: 10px;
}
/deep/ .el-table__body-wrapper {
    border-bottom-left-radius: 10px;
    border-bottom-right-radius: 10px;
}
/deep/ .el-table {
    background-color: transparent;
}
.container {
    padding: 30px;
    overflow: auto;
    box-sizing: border-box;

    .header {
        height: 59px;
        width: 100%;
        display: flex;
        justify-content: space-between;
        border-bottom: 1px solid #4d7faf;
        .title {
            display: flex;
            height: 34px;
            align-items: center;
            .title-icon {
                display: block;
                width: 28px;
                height: 28px;
                background-image: url('../../assets/img/icon-标题@2x.png');
                background-size: 100% 100%;
            }
            .title-text {
                margin-left: 5px;
                height: 34px;
                font-size: 26px;
                font-family: Microsoft YaHei, Microsoft YaHei;
                font-weight: 700;
                line-height: 34px;
                color: transparent;
                -webkit-background-clip: text;
                background-image: linear-gradient(180deg, #e5f2ff 24%, #1f5c99 100%);
            }
        }
        .back-icon {
            margin-right: 10px;
            cursor: pointer;
            display: block;
            width: 40px;
            height: 40px;
            background-size: 100% 100%;
            background-image: url(../../assets//img/icon-返回@2x.png);
        }
    }
    .search {
        margin-top: 32px;
    }
    .table {
        margin-top: 12px;
        width: 100%;
        /deep/ .custom-header-cell {
            background-color: #145080 !important;
            padding: 15px 0;
            .cell {
                font-size: 18px;
                font-family: Microsoft YaHei, Microsoft YaHei;
                font-weight: 700;
                color: #e7edf0;
            }
        }
        /deep/ .custom-cell {
            padding: 15px 0;
            cursor: pointer;
            .cell,
            div {
                font-size: 16px;
                font-family: Microsoft YaHei, Microsoft YaHei;
                font-weight: 400;
                color: #e5f2ff;
            }
        }
        .table-total {
            display: flex;
            justify-content: center;
            align-items: center;
            height: 64px;
            background-color: #145080;
            border-radius: 10px;
            margin-top: 8px;
            span {
                font-size: 18px;
                font-family: Microsoft YaHei, Microsoft YaHei;
                font-weight: 700;
                color: #e7edf0;
                text-align: center;
                &:nth-child(1) {
                    width: 70px;
                }
                &:not(:nth-child(1)) {
                    flex: 1;
                }
            }
        }
    }
    .charts {
        margin-top: 32px;
        display: flex;
        .charts-border {
            position: relative;
            height: 507px;
            flex: 1;
            background-size: 100% 100%;
            background-image: url('../../assets/img/框@2x.png');
            .charts_title {
                display: flex;
                height: 24px;
                align-items: center;
                position: absolute;
                top: 30px;
                left: 25px;
            }
            .charts_title-icon {
                display: block;
                width: 20px;
                height: 20px;
                background-size: 100% 100%;
                background-image: url('../../assets/img/icon-饼图@2x.png');
            }
            .clumn-icon {
                background-image: url('../../assets/img/icon-柱图@2x.png');
            }
            .yhxt-B-zhexiantu {
                color: transparent;
                -webkit-background-clip: text;
                background-image: linear-gradient(180deg, #e5f2ff 24%, #1f5c99 100%);
            }
            .charts_title-text {
                margin-left: 5px;
                height: 24px;
                font-size: 18px;
                font-family: Microsoft YaHei, Microsoft YaHei;
                font-weight: 700;
                line-height: 24px;
                color: transparent;
                -webkit-background-clip: text;
                background-image: linear-gradient(180deg, #e5f2ff 24%, #1f5c99 100%);
            }
        }
    }
}
</style>
